==> parselglossy-0.1.0.tar.gz: parselglossy-0.1.0/parselglossy/__init__.py <==
#
# parselglossy -- Generic input parsing library, speaking in tongues
# Copyright (C) 2018 Roberto Di Remigio, and contributors.
#
# This file is part of parselglossy.
#
# Permission is hereby granted, free of charge, to any person obtaining a copy
# of this software and associated documentation files (the "Software"), to deal
# in the Software without restriction, including without limitation the rights
# to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
# copies of the Software, and to permit persons to whom the Software is
# furnished to do so, subject to the following conditions:
#
# The above copyright notice and this permission notice shall be included in
# all copies or substantial portions of the Software.
#
# THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
# IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
# FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
# Roberto Di Remigio, and contributors. OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
# LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
# OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
# SOFTWARE.
#
# For information on the complete list of contributors to the
# parselglossy library, see: <http://parselglossy.readthedocs.io/>
#

# -*- coding: utf-8 -*-
"""Top-level package for parselglossy."""

__author__ = """Roberto Di Remigio"""
__email__ = 'roberto.diremigio@gmail.com'
__version__ = '0.1.0'
__copyright__ = "Copyright 2018, dev-cafe"
__credits__ = [
    "Jonas Juselius", "Roberto Di Remigio", "Radovan Bast", "Luca Frediani",
    "Stig Rune Jensen", "Ville Weijo"
]
__license__ = "MIT"
__maintainer__ = "Roberto Di Remigio, Radovan Bast, Stig Rune Jensen"
__status__ = "Production"

==> parselglossy-0.3.0a6.tar.gz: parselglossy-0.3.0a6/parselglossy/__init__.py <==
#
# parselglossy -- Generic input parsing library, speaking in tongues
# Copyright (C) 2019 Roberto Di Remigio, Radovan Bast, and contributors.
#
# This file is part of parselglossy.
#
# Permission is hereby granted, free of charge, to any person obtaining a copy
# of this software and associated documentation files (the "Software"), to deal
# in the Software without restriction, including without limitation the rights
# to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
# copies of the Software, and to permit persons to whom the Software is
# furnished to do so, subject to the following conditions:
#
# The above copyright notice and this permission notice shall be included in
# all copies or substantial portions of the Software.
#
# THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
# IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
# FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
# AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
# LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
# OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
# SOFTWARE.
#
# For information on the complete list of contributors to the
# parselglossy library, see: <http://parselglossy.readthedocs.io/>
#

# -*- coding: utf-8 -*-
"""Top-level package for parselglossy."""

__author__ = """Roberto Di Remigio, Radovan Bast"""
__email__ = "roberto.diremigio@gmail.com"
__version__ = "0.3.0-alpha6"
__copyright__ = "Copyright 2019, dev-cafe"
__credits__ = [
    "Jonas Juselius",
    "Roberto Di Remigio",
    "Radovan Bast",
    "Luca Frediani",
    "Stig Rune Jensen",
    "Ville Weijo",
]
__license__ = "MIT"
__maintainer__ = "Roberto Di Remigio, Radovan Bast, Stig Rune Jensen"
__status__ = "Production"
